==> bee-ui-0.0.21-201708160249-201708160249-201708160249.tgz: package/src/TabScene/README.md <==
### TabScene组件: 特别提醒如果TabScene不在最顶层，请在顶层设置<View style={{flex:1}}>否则下面的content容器不显示

| 参数名称 | 描述 | 类型 | 属性值 | 默认值|
|---|---|---|---|---|
| tabLabel | 设置每个tab按钮的titile | `String` | -- | -- |
| tabBarPosition | 设置tabBar的布局位置，顶部或底部 | `String` | `top` |
| initialPage | 设置初始时activeTab的key | `Number` | `0` |
| onChangeTab | callback函数 | `function` | (obj)=>{} | `{ i:currentKey, from: prevKey, ref: dom }`
| renderTabBar | 要渲染的tabBar组件,通过向该函数传递自定义组件来修改默认的tabBarCompontent |`func` | 默认自动渲染`TabBarCompontent` |
| tabActiveText | 焦点文字颜色样式 | `Text.propTypes.style` | Object |`{color: #82A0FA }`|
| tabDefaultText | 普通文字颜色样式 | `Text.propTypes.style` | Object |`{color: #888 }`|
| tabBarStyle | 设置整个tabBar容器组件的样式 | `Text.propTypes.style` | Object | `null`




<!-- | tabUnderLineStyle | 下划线的样式 | `Text.propTypes.style` |`style`|`{ position: 'absolute',width: containerWidth / tabs.length,height: 2,backgroundColor: '#82A0FA',bottom: 0 }`|  -->
       

```jsx
  static propTypes = {
    tabBarPosition: PropTypes.oneOf(['top', 'bottom']),
    initialPage: PropTypes.number,
    onChangeTab: PropTypes.func,
    onScroll: PropTypes.func,
    renderTabBar: PropTypes.func,
    style: ViewStylePropTypes || (View.propTypes && View.propTypes.style),
    contentProps: PropTypes.object,
    tabActiveText: Text.propTypes.style,
    tabDeafultText: Text.propTypes.style,
    tabBackground: ViewStylePropTypes || (View.propTypes && View.propTypes.style),
    tabBarBarbackground: ViewStylePropTypes || (View.propTypes && View.propTypes.style,
    tabUnderLineStyle: ViewStylePropTypes || (View.propTypes && View.propTypes.style),
  }
```

```jsx
  static defaultProps = {
      tabBarPosition: 'top',
      initialPage: 0,
      page: -1,
      onChangeTab: () => {},
  }
```

```jsx
const styles = StyleSheet.create({
  tabActiveText: {
    color: '#82A0FA',
  },
  tabDeafultText: {
    color: '#888',
  },
  tabBackground: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    paddingBottom: 10,
  },
  defaultTabBarStyle: {
    height: 50,
    flexDirection: 'row',
    justifyContent: 'space-around',
    borderWidth: 1,
    borderTopWidth: 0,
    borderLeftWidth: 0,
    borderRightWidth: 0,
    borderColor: '#ccc',
  },
});
```


###  Sample Code

```jsx
<View style={{ marginTop: 30 }}>
  <TabScene>
    <View tabLabel="全部">
      <Text>全部</Text>
    </View>
    <View tabLabel="未审阅">
      <Text>未审阅</Text>
    </View>
    <View tabLabel="已审阅">
      <Text>已审阅</Text>
    </View>
  </TabScene>
  <TabScene
    defaultTextStyle={{ color: '#fff' }}
    activeTextStyle={{ color: 'red' }}
    tabBarStyle={{
      backgroundColor: '#82A0FA',
      height: 70,
    }}
    onChangeTab={onChangeTabFn}
  >
    <View tabLabel="React">
      <Text>vs ！ Vue </Text>
    </View>
    <View tabLabel="Vue">
      <Text>vs ! React </Text>
    </View>
    <View tabLabel="React-Native">
      <Text>坑</Text>
    </View>
  </TabScene>
</View>
```

==> bee-ui-0.0.40.tgz: package/src/TabScene/README.md <==
### TabScene组件: 特别提醒如果TabScene不在最顶层，请在顶层设置<View style={{flex:1}}>否则下面的content容器不显示

| 参数名称 | 描述 | 类型 | 属性值 | 默认值|
|---|---|---|---|---|
| tabLabel | 设置每个tab按钮的titile | `String` | -- | -- |
| tabBarPosition | 设置tabBar的布局位置，顶部或底部 | `String` | `top`, `bottom` |
| initialPage | 设置初始时activeTab的key | `Number` | `0` |
| onChangeTab | callback函数 | `function` | (obj)=>{} | `{ i:currentKey, from: prevKey, ref: dom }`
| renderTabBar | 要渲染的tabBar组件,通过向该函数传递自定义组件来修改默认的tabBarCompontent |`func` | 默认自动渲染`TabBarCompontent` |
| tabActiveText | 焦点文字颜色样式 | `Text.propTypes.style` | Object |`{color: #82A0FA }`|
| tabDefaultText | 普通文字颜色样式 | `Text.propTypes.style` | Object |`{color: #888 }`|
| tabBarStyle | 设置整个tabBar容器组件的样式 | `Text.propTypes.style` | Object | `null`

> 如果不想用onChangeTab方法来做回调,可以在每个内容容器下绑定onActive和onDeactive事件


![image](../assets/TabScene_design.png);
![image](../assets/tabScene_design.png);
       

```jsx
  static propTypes = {
    tabBarPosition: PropTypes.oneOf(['top', 'bottom']),
    initialPage: PropTypes.number,
    onChangeTab: PropTypes.func,
    onScroll: PropTypes.func,
    renderTabBar: PropTypes.func,
    style: ViewStylePropTypes || (View.propTypes && View.propTypes.style),
    contentProps: PropTypes.object,
    tabActiveText: Text.propTypes.style,
    tabDeafultText: Text.propTypes.style,
    tabBackground: ViewStylePropTypes || (View.propTypes && View.propTypes.style),
    tabBarBarbackground: ViewStylePropTypes || (View.propTypes && View.propTypes.style,
    tabUnderLineStyle: ViewStylePropTypes || (View.propTypes && View.propTypes.style),
  }
```

```jsx
  static defaultProps = {
      tabBarPosition: 'top',
      initialPage: 0,
      page: -1,
      onChangeTab: () => {},
  }
```

```jsx
const styles = StyleSheet.create({
  tabActiveText: {
    color: '#82A0FA',
  },
  tabDeafultText: {
    color: '#888',
  },
  tabBackground: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    paddingBottom: 10,
  },
  defaultTabBarStyle: {
    height: 50,
    flexDirection: 'row',
    justifyContent: 'space-around',
    borderWidth: 1,
    borderTopWidth: 0,
    borderLeftWidth: 0,
    borderRightWidth: 0,
    borderColor: '#ccc',
  },
});
```


###  Sample Code

```jsx
<View style={{ marginTop: 30 }}>
  <TabScene>
    <View tabLabel="全部" onActive={()=>{conosle.log('获得焦点触发函数01')}} onDeactive={()=>{console.log('失去焦点时触发此事件01')}}>
      <Text>全部</Text>
    </View>
    <View tabLabel="未审阅" onActive={()=>{conosle.log('获得焦点触发函数02')}} onDeactive={()=>{console.log('失去焦点时触发此事件02')}}>
      <Text>未审阅</Text>
    </View>
    <View tabLabel="已审阅" onActive={()=>{conosle.log('获得焦点触发函数03')}} onDeactive={()=>{console.log('失去焦点时触发此事件03')}}>
      <Text>已审阅</Text>
    </View>
  </TabScene>
  <TabScene
    defaultTextStyle={{ color: '#fff' }}
    activeTextStyle={{ color: 'red' }}
    tabBarStyle={{
      backgroundColor: '#82A0FA',
      height: 70,
    }}
    onChangeTab={onChangeTabFn}
  >
    <View tabLabel="React">
      <Text>vs ！ Vue </Text>
    </View>
    <View tabLabel="Vue">
      <Text>vs ! React </Text>
    </View>
    <View tabLabel="React-Native">
      <Text>坑</Text>
    </View>
  </TabScene>
</View>
```
